@@ -108,7 +108,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
-#include <assert.h>
 
 /* SSLeay headers */
 #include <ssl.h>
@@ -491,6 +490,7 @@ static void init_Module(server_rec *s, pool *p)
     char *szLogFile;
     char buf[MAX_STRING_LEN];
     static int nStashStdin, nStashStderr, nSaveStdin, nSaveStderr;
+    server_rec *pMainServer = s;
     piped_log *pl;
     char *cp;
     char *cp2;
@@ -539,11 +539,6 @@ static void init_Module(server_rec *s, pool *p)
         exit(1);
     }
 
-    /*
-     *  launch SSL session cache program
-     */
-    LaunchCache(s, p);
-
     /*
      *  initialize SSLeay
      */
@@ -636,6 +631,11 @@ static void init_Module(server_rec *s, pool *p)
         init_GetCertAndKey(s, p, pConfig);
     }
 
+    /*
+     *  launch SSL session cache process
+     */
+    LaunchCache(pMainServer, p);
+
     /* 
      *  Restore STDIO fds to their old values
      */
@@ -673,7 +673,6 @@ static void init_SSLeay(server_rec *s, pool *p)
      *  Fire up the SSLeay internals 
      */
     __SSLeay SSL_load_error_strings();
-    __SSLeay ERR_load_crypto_strings();
     __SSLeay SSLeay_add_ssl_algorithms();
 
     return;
@@ -875,10 +874,8 @@ static int init_VerifyFlags(SSLConfigRec *pConfig)
      */
     fb->ssl = __SSLeay SSL_new(pConfig->pSSLCtx);
     __SSLeay SSL_set_fd(fb->ssl, fb->fd);
-#if FREE_SESSION
-    ap_register_cleanup(conn->pool, conn, 
+    ap_register_cleanup(conn->pool, (void *)conn, 
                         SSL_HOOK_CloseConnection, SSL_HOOK_CloseConnection);
-#endif
 
     /*
      * Now SSL verify the connection
@@ -939,22 +936,20 @@ static int init_VerifyFlags(SSLConfigRec *pConfig)
     return TRUE;
 }
 
-#if FREE_SESSION
 /*
- * To make this work, SSL_free() needs to be patched inside SSLeay. 
- * Remove from SSL_free: if (s->ctx) SSL_CTX_free(s->ctx);
- * But there's more, which I haven't found. -- ben
+ *  Close the SSL part of the socket connection
  */
 static void SSL_HOOK_CloseConnection(void *_conn)
 {
     conn_rec *conn = _conn;
     SSL *ssl = conn->client->ssl;
 
-    __SSLeay SSL_set_shutdown(ssl, SSL_SENT_SHUTDOWN|SSL_RECEIVED_SHUTDOWN);
-    __SSLeay SSL_free(ssl);
-    /* ap_log_error(APLOG_MARK,APLOG_DEBUG|APLOG_NOERRNO,conn->server, "Closed"); */
+    if (ssl != NULL) {
+        __SSLeay SSL_set_shutdown(ssl, SSL_SENT_SHUTDOWN|SSL_RECEIVED_SHUTDOWN);
+        __SSLeay SSL_free(ssl);
+    }
+    return;
 }
-#endif
 
 /*
  *  Auth Handler:
@@ -1338,7 +1333,6 @@ static int CacheLauncher(void *cmd, child_info *pInfo)
     ap_cleanup_for_exec();
     execl(cmd, "ssl_gcache", a1, g_szCacheServerPort, NULL);
     perror(cmd);
-    assert(0);
     return 1;
 }
 
@@ -1360,12 +1354,11 @@ static void SendSessionToServer(SSL_SESSION *pSession)
 
     t = malloc(pSession->session_id_length);
     memcpy(t, pSession->session_id, pSession->session_id_length);
-    p = LocalCacheAdd(t, pSession->session_id_length, tExpiresAt);
+    if ((p = LocalCacheAdd(t, pSession->session_id_length, tExpiresAt)) == NULL)
+        return;
 
     t = buf;
     nLength = __SSLeay i2d_SSL_SESSION(pSession, &t);
-    assert(nLength > 0);
-    assert(nLength <= MAX_SESSION_DER);
 
     p->aucData = malloc(nLength);
     memcpy(p->aucData, buf, nLength);
@@ -1399,9 +1392,8 @@ static SSL_SESSION *GetSessionFromServer(uchar *aucSessionID, int nLength)
         nData = p->nData;
     }
     pSession = __SSLeay d2i_SSL_SESSION(NULL, &t, nData);
-    if (!pSession)
+    if (pSession == NULL)
         __SSLeay ERR_print_errors_fp(stderr);
-    assert(pSession);
     return pSession;
 }
 
