@@ -128,22 +128,15 @@ typedef unsigned char uchar;
  * Give an error if SSLeay below 0.8.0 is used 
  */
 #if SSLEAY_VERSION_NUMBER < 0x0800
-#error "SSLeay versions below 0.8.0 are no longer supported"
+#error "SSLeay versions below 0.8.0 are not supported"
 #endif
 
 /* 
- * Define this to TRUE when SSLeay can do an 
- * SSL_free() without falling over 
- */
-#define FREE_SESSION    FALSE
-
-/* 
- * Define this to TRUE to debug the SSL verification,
- * the SSL session caching stuff or even SSLeay itself
+ * Define this to TRUE to debug the SSL verification
+ * or the SSL session caching stuff
  */
 #define DEBUG_VERIFY    FALSE
 #define DEBUG_SESSIONS  FALSE
-#define DEBUG_SSLEAY    FALSE
 
 /*
  * Correct a typo in SSLeay 
@@ -233,9 +226,7 @@ static int          init_VerifyFlags(SSLConfigRec *);
 
 /*  Apache API hooks  */
 /*NONSTATIC*/ int   SSL_HOOK_SetupConnection(conn_rec *);
-#if FREE_SESSION
 static void         SSL_HOOK_CloseConnection(void *);
-#endif
 static int          ssl_hook_Auth(request_rec *);
 static int          ssl_hook_Access(request_rec *);
 static int          ssl_hook_Fixup(request_rec *);
