@@ -116,7 +116,6 @@
 char *get_time(void);
 void HandleGet(int nFD);
 void HandleClient(int nFD);
-void Dump(const char *szName, uchar * p, int n);
 void signal_handler(int sig);
 
 typedef union {
@@ -126,18 +125,6 @@ typedef union {
 
 char *progname = NULL;
 
-#if DEBUG
-void Dump(const char *szName, uchar * p, int n)
-{
-    printf("%s(", szName);
-    for (; n-- > 0; ++p)
-        printf("%02x", *p);
-    printf(")\n");
-}
-#else
-#define Dump(a,b,c)
-#endif
-
 /*
  * In an ideal world, this would come from some Apache supplied library,
  * but well... just try it :-)
@@ -160,7 +147,6 @@ static void HandleAdd(int nFD)
     Cache *p;
 
     aucKey = ReadThing(nFD, &nKey);
-    Dump("Add", aucKey, nKey);
     p = LocalCacheFind(aucKey, nKey);
     if (p) {
         free(p->aucData);
@@ -179,13 +165,9 @@ void HandleGet(int nFD)
     Cache *p;
 
     aucKey = ReadThing(nFD, &nKey);
-    Dump("Get", aucKey, nKey);
     p = LocalCacheFind(aucKey, nKey);
     if (!p) {
         WriteThing(nFD, NULL, 0);
-#if DEBUG
-        printf("Miss!\n");
-#endif
     }
     else {
         WriteThing(nFD, p->aucData, p->nData);
